@@ -10,8 +10,8 @@ from .exceptions import CimisError, CimisAPIError, CimisDataError, CimisConnecti
 from .models import WeatherData, Station, ZipCode, SpatialZipCode
 
 __version__ = "1.0.0"
-__author__ = "Python CIMIS Client Team"
-__email__ = "contact@python-cimis.dev"
+__author__ = "Mahipal Reddy Ramireddy"
+__email__ = "mahipalbablu16@gmail.com"
 __description__ = "A comprehensive Python client for the California Irrigation Management Information System (CIMIS) API"
 
 __all__ = [
