@@ -63,6 +63,31 @@ class CimisClient:
         # Use filename generator for automatic CSV file naming
         self.filename_generator = FilenameGenerator()
     
+    # Properties for backward compatibility
+    @property
+    def BASE_URL(self):
+        """Base URL for CIMIS API (for backward compatibility)."""
+        return self.endpoints.BASE_URL
+    
+    @property
+    def DEFAULT_DAILY_DATA_ITEMS(self):
+        """Default daily data items (for backward compatibility)."""
+        return self.endpoints.DEFAULT_DAILY_DATA_ITEMS
+    
+    @property
+    def DEFAULT_HOURLY_DATA_ITEMS(self):
+        """Default hourly data items (for backward compatibility)."""
+        return self.endpoints.DEFAULT_HOURLY_DATA_ITEMS
+    
+    def _is_coordinate_list(self, targets):
+        """Check if targets contain coordinate strings (for backward compatibility)."""
+        if not targets:
+            return False
+        for target in targets:
+            if isinstance(target, str) and 'lat=' in target and 'lng=' in target:
+                return True
+        return False
+    
     def _make_request(self, endpoint_key: str, params: Dict[str, Any], **endpoint_kwargs) -> Dict[str, Any]:
         """
         Make a request to the CIMIS API using centralized endpoint management.
@@ -224,7 +249,7 @@ class CimisClient:
                        start_date: Union[str, date, datetime],
                        end_date: Union[str, date, datetime],
                        data_items: Optional[List[str]] = None,
-                       unit_of_measure: str = 'English',
+                       unit_of_measure: str = 'Metric',
                        prioritize_scs: bool = True,
                        csv: bool = False,
                        filename: Optional[Union[str, Path]] = None) -> Union[WeatherData, tuple[WeatherData, str]]:
@@ -238,7 +263,7 @@ class CimisClient:
             start_date: Start date for data retrieval
             end_date: End date for data retrieval
             data_items: List of data items to retrieve (uses default if None)
-            unit_of_measure: 'English' for English units or 'Metric' for Metric units
+            unit_of_measure: 'Metric' for Metric units (default) or 'English' for English units
             prioritize_scs: Whether to prioritize SCS data for zip codes
             csv: If True, automatically export to CSV with auto-generated filename
             filename: Custom filename for CSV export (only used if csv=True)
@@ -266,7 +291,7 @@ class CimisClient:
                         start_date: Union[str, date, datetime],
                         end_date: Union[str, date, datetime],
                         data_items: Optional[List[str]] = None,
-                        unit_of_measure: str = 'English',
+                        unit_of_measure: str = 'Metric',
                         csv: bool = False,
                         filename: Optional[Union[str, Path]] = None) -> Union[WeatherData, tuple[WeatherData, str]]:
         """
@@ -280,7 +305,7 @@ class CimisClient:
             start_date: Start date for data retrieval
             end_date: End date for data retrieval
             data_items: List of data items to retrieve (uses default if None)
-            unit_of_measure: 'English' for English units or 'Metric' for Metric units
+            unit_of_measure: 'Metric' for Metric units (default) or 'English' for English units
             csv: If True, automatically export to CSV with auto-generated filename (hourly only)
             filename: Custom filename for CSV export (only used if csv=True)
             
@@ -516,10 +541,15 @@ class CimisClient:
         # Data value columns (value, qc, unit for each data item)
         data_columns = []
         for item in sorted_data_items:
+            # Remove "Hly" prefix for hourly columns to make them cleaner
+            clean_item_name = item
+            if item.startswith('Hly'):
+                clean_item_name = item[3:]  # Remove "Hly" prefix
+            
             data_columns.extend([
-                f"{item}_Value",
-                f"{item}_QC", 
-                f"{item}_Unit"
+                f"{clean_item_name}_Value",
+                f"{clean_item_name}_QC", 
+                f"{clean_item_name}_Unit"
             ])
         
         all_columns = base_columns + data_columns
@@ -605,28 +635,33 @@ class CimisClient:
                     
                     # Add data values - only include items that are in our filtered set
                     for item in sorted_data_items:
+                        # Remove "Hly" prefix for column names to make them cleaner
+                        clean_item_name = item
+                        if item.startswith('Hly'):
+                            clean_item_name = item[3:]  # Remove "Hly" prefix
+                        
                         if hasattr(record, 'data_values'):
                             # WeatherRecord object
                             data_value = record_data_values.get(item)
                             if data_value:
-                                row[f"{item}_Value"] = data_value.value or ''
-                                row[f"{item}_QC"] = data_value.qc
-                                row[f"{item}_Unit"] = data_value.unit
+                                row[f"{clean_item_name}_Value"] = data_value.value or ''
+                                row[f"{clean_item_name}_QC"] = data_value.qc
+                                row[f"{clean_item_name}_Unit"] = data_value.unit
                             else:
-                                row[f"{item}_Value"] = ''
-                                row[f"{item}_QC"] = ''
-                                row[f"{item}_Unit"] = ''
+                                row[f"{clean_item_name}_Value"] = ''
+                                row[f"{clean_item_name}_QC"] = ''
+                                row[f"{clean_item_name}_Unit"] = ''
                         else:
                             # Dict object (legacy support)
                             item_data = record_data_values.get(item)
                             if item_data and isinstance(item_data, dict):
-                                row[f"{item}_Value"] = item_data.get('Value', '')
-                                row[f"{item}_QC"] = item_data.get('QC', '')
-                                row[f"{item}_Unit"] = item_data.get('Unit', '')
+                                row[f"{clean_item_name}_Value"] = item_data.get('Value', '')
+                                row[f"{clean_item_name}_QC"] = item_data.get('QC', '')
+                                row[f"{clean_item_name}_Unit"] = item_data.get('Unit', '')
                             else:
-                                row[f"{item}_Value"] = ''
-                                row[f"{item}_QC"] = ''
-                                row[f"{item}_Unit"] = ''
+                                row[f"{clean_item_name}_Value"] = ''
+                                row[f"{clean_item_name}_QC"] = ''
+                                row[f"{clean_item_name}_Unit"] = ''
                     
                     writer.writerow(row)
         
